schemas/bootstrap.py
changeset 2476 1294a6bdf3bf
parent 2459 d088d0ff48a1
child 3392 36bcf206e157
child 3877 7ca53fc72a0a
child 4212 ab6573088b4a
--- a/schemas/bootstrap.py	Fri Jul 24 13:50:59 2009 +0200
+++ b/schemas/bootstrap.py	Fri Jul 24 14:33:37 2009 +0200
@@ -1,4 +1,4 @@
 """core CubicWeb schema necessary for bootstrapping the actual application's schema
 
 :organization: Logilab
 :copyright: 2001-2009 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
@@ -16,7 +16,7 @@
 # not restricted since as "is" is handled as other relations, guests need
 # access to this
 class CWEType(EntityType):
-    """define an entity type, used to build the application schema"""
+    """define an entity type, used to build the instance schema"""
     permissions = META_ETYPE_PERMS
     name = String(required=True, indexed=True, internationalizable=True,
                   unique=True, maxsize=64)
@@ -27,7 +27,7 @@
 
 
 class CWRType(EntityType):
-    """define a relation type, used to build the application schema"""
+    """define a relation type, used to build the instance schema"""
     permissions = META_ETYPE_PERMS
     name = String(required=True, indexed=True, internationalizable=True,
                   unique=True, maxsize=64)
@@ -46,7 +46,7 @@
     """define a final relation: link a final relation type from a non final
     entity to a final entity type.
 
-    used to build the application schema
+    used to build the instance schema
     """
     permissions = META_ETYPE_PERMS
     relation_type = SubjectRelation('CWRType', cardinality='1*',
@@ -83,7 +83,7 @@
     """define a non final relation: link a non final relation type from a non
     final entity to a non final entity type.
 
-    used to build the application schema
+    used to build the instance schema
     """
     permissions = META_ETYPE_PERMS
     relation_type = SubjectRelation('CWRType', cardinality='1*',
@@ -1,4 +1,4 @@
-"""core CubicWeb schema necessary for bootstrapping the actual application's schema
+"""core CubicWeb schema necessary for bootstrapping the actual instance's schema
 
 :organization: Logilab